@@ -17,7 +17,7 @@
 """
 """
 
-__all__ = ['collection', 'Collection', 'MutableCollection', 'MutableSequence', 'setlist', 'frozensetlist', 'bag', 'frozenbag']
+__all__ = ['collection', 'Collection', 'MutableCollection', 'MutableSequence', 'Set', 'setlist', 'frozensetlist', 'bag', 'frozenbag']
 
 from abc import ABCMeta, abstractmethod
 import heapq
@@ -134,6 +134,12 @@ MutableCollection.register(MutableSet)
 ## Extending built-in classes
 #####################################################################
 
+class Set(Set):
+	""" Extended Set to efficiently count elements. """
+
+	def count(self, elem):
+		return elem in self
+
 class MutableSequence(MutableSequence):
 	""" Extended MutableSequence to fit Collection ABC """
 
@@ -514,7 +520,7 @@ class _basebag(Collection):
 		
 		This runs in O(1) time
 		"""
-		return set(self._dict.keys())
+		return self._dict.keys()
 
 	def count(self, value):
 		""" Return the multiplicity of value.  If value is not in the bag no Error is
